==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/contacts/CNPostalAddress.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.contacts;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 9.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("Contacts") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/CNPostalAddress/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class CNPostalAddressPtr extends Ptr<CNPostalAddress, CNPostalAddressPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(CNPostalAddress.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public CNPostalAddress() {}
    protected CNPostalAddress(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "street")
    public native String getStreet();
    @Property(selector = "city")
    public native String getCity();
    @Property(selector = "state")
    public native String getState();
    @Property(selector = "postalCode")
    public native String getPostalCode();
    @Property(selector = "country")
    public native String getCountry();
    @Property(selector = "ISOCountryCode")
    public native String getISOCountryCode();
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "localizedStringForKey:")
    public static native String getLocalizedProperty(CNPostalAddressPropertyKey key);
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/contacts/CNPostalAddress.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.contacts;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 9.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("Contacts") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/CNPostalAddress/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*/implements NSSecureCoding/*</implements>*/ {

    /*<ptr>*/public static class CNPostalAddressPtr extends Ptr<CNPostalAddress, CNPostalAddressPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(CNPostalAddress.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public CNPostalAddress() {}
    protected CNPostalAddress(Handle h, long handle) { super(h, handle); }
    protected CNPostalAddress(SkipInit skipInit) { super(skipInit); }
    @Method(selector = "initWithCoder:")
    public CNPostalAddress(NSCoder coder) { super((SkipInit) null); initObject(init(coder)); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "street")
    public native String getStreet();
    /**
     * @since Available in iOS 10.3 and later.
     */
    @Property(selector = "subLocality")
    public native String getSubLocality();
    @Property(selector = "city")
    public native String getCity();
    /**
     * @since Available in iOS 10.3 and later.
     */
    @Property(selector = "subAdministrativeArea")
    public native String getSubAdministrativeArea();
    @Property(selector = "state")
    public native String getState();
    @Property(selector = "postalCode")
    public native String getPostalCode();
    @Property(selector = "country")
    public native String getCountry();
    @Property(selector = "ISOCountryCode")
    public native String getISOCountryCode();
    @Property(selector = "supportsSecureCoding")
    public static native boolean supportsSecureCoding();
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "localizedStringForKey:")
    public static native String getLocalizedProperty(CNPostalAddressPropertyKey key);
    @Method(selector = "encodeWithCoder:")
    public native void encode(NSCoder coder);
    @Method(selector = "initWithCoder:")
    protected native @Pointer long init(NSCoder coder);
    /*</methods>*/
}
